@@ -90,6 +90,9 @@ describe 'ironic::conductor' do
       is_expected.to contain_ironic_config('conductor/rescue_ramdisk').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/bootloader').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/image_download_concurrency').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/deploy_callback_timeout').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/heartbeat_interval').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/heartbeat_timeout').with(:value => '<SERVICE DEFAULT>')
     end
 
     context 'when overriding parameters' do
@@ -99,7 +102,6 @@ describe 'ironic::conductor' do
           :force_power_state_during_sync     => false,
           :automated_clean                   => false,
           :cleaning_network                  => '00000000-0000-0000-0000-000000000000',
-          :api_url                           => 'https://127.0.0.1:6385',
           :provisioning_network              => '00000000-0000-0000-0000-000000000000',
           :rescuing_network                  => '00000000-0000-0000-0000-000000000000',
           :inspection_network                => '00000000-0000-0000-0000-000000000000',
@@ -127,13 +129,15 @@ describe 'ironic::conductor' do
           :bootloader                        => 'http://host/bootloader',
           :allow_provisioning_in_maintenance => false,
           :image_download_concurrency        => 20,
+          :deploy_callback_timeout           => 1800,
+          :heartbeat_interval                => 10,
+          :heartbeat_timeout                 => 60,
         )
       end
       it 'should replace default parameter with new value' do
         is_expected.to contain_ironic_config('DEFAULT/enabled_hardware_types').with_value('ipmi,irmc')
         is_expected.to contain_ironic_config('conductor/force_power_state_during_sync').with_value(p[:force_power_state_during_sync])
         is_expected.to contain_ironic_config('conductor/automated_clean').with_value(p[:automated_clean])
-        is_expected.to contain_ironic_config('conductor/api_url').with_value(p[:api_url])
         is_expected.to contain_ironic_config('neutron/cleaning_network').with_value('00000000-0000-0000-0000-000000000000')
         is_expected.to contain_ironic_config('neutron/provisioning_network').with_value('00000000-0000-0000-0000-000000000000')
         is_expected.to contain_ironic_config('neutron/rescuing_network').with_value('00000000-0000-0000-0000-000000000000')
@@ -163,6 +167,9 @@ describe 'ironic::conductor' do
         is_expected.to contain_ironic_config('conductor/bootloader').with_value(p[:bootloader])
         is_expected.to contain_ironic_config('conductor/allow_provisioning_in_maintenance').with_value(p[:allow_provisioning_in_maintenance])
         is_expected.to contain_ironic_config('DEFAULT/image_download_concurrency').with_value(p[:image_download_concurrency])
+        is_expected.to contain_ironic_config('conductor/deploy_callback_timeout').with_value(p[:deploy_callback_timeout])
+        is_expected.to contain_ironic_config('conductor/heartbeat_interval').with_value(p[:heartbeat_interval])
+        is_expected.to contain_ironic_config('conductor/heartbeat_timeout').with_value(p[:heartbeat_timeout])
       end
     end
 
