@@ -25,7 +25,7 @@ describe 'ironic::drivers::drac' do
 
     it 'installs dracclient package' do
       is_expected.to contain_package('python-dracclient').with(
-        :ensure => 'present',
+        :ensure => 'installed',
         :name   => platform_params[:dracclient_package_name],
         :tag    => ['openstack', 'ironic-package'],
       )
@@ -46,15 +46,7 @@ describe 'ironic::drivers::drac' do
         when 'Debian'
           { :dracclient_package_name => 'python3-dracclient' }
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :dracclient_package_name => 'python3-dracclient' }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :dracclient_package_name => 'python3-dracclient' }
-            else
-              { :dracclient_package_name => 'python-dracclient' }
-            end
-          end
+          { :dracclient_package_name => 'python3-dracclient' }
         end
       end
 
