@@ -35,7 +35,7 @@ describe 'ironic::drivers::ilo' do
 
     it 'installs proliantutils package' do
       is_expected.to contain_package('python-proliantutils').with(
-        :ensure => 'present',
+        :ensure => 'installed',
         :name   => platform_params[:proliantutils_package_name],
         :tag    => ['openstack', 'ironic-package'],
       )
@@ -71,15 +71,7 @@ describe 'ironic::drivers::ilo' do
         when 'Debian'
           { :proliantutils_package_name => 'python3-proliantutils' }
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :proliantutils_package_name => 'python3-proliantutils' }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :proliantutils_package_name => 'python3-proliantutils' }
-            else
-              { :proliantutils_package_name => 'python-proliantutils' }
-            end
-          end
+          { :proliantutils_package_name => 'python3-proliantutils' }
         end
       end
 
