@@ -12,6 +12,7 @@ describe 'ironic::inspector::db' do
         :max_retries             => '<SERVICE DEFAULT>',
         :db_max_retries          => '<SERVICE DEFAULT>',
         :pool_timeout            => '<SERVICE DEFAULT>',
+        :mysql_enable_ndb        => '<SERVICE DEFAULT>',
         :retry_interval          => '<SERVICE DEFAULT>',
         :max_overflow            => '<SERVICE DEFAULT>',
       )}
@@ -27,6 +28,7 @@ describe 'ironic::inspector::db' do
           :database_db_max_retries          => '11',
           :database_max_overflow            => '21',
           :database_pool_timeout            => '21',
+          :mysql_enable_ndb                 => true,
           :database_retry_interval          => '11', }
       end
 
@@ -37,6 +39,7 @@ describe 'ironic::inspector::db' do
         :max_retries             => '11',
         :db_max_retries          => '11',
         :pool_timeout            => '21',
+        :mysql_enable_ndb        => true,
         :retry_interval          => '11',
         :max_overflow            => '21',
       )}
