@@ -102,10 +102,12 @@ describe 'ironic::inspector' do
     end
 
     it 'ensure ironic inspector dnsmasq service is running' do
-      is_expected.to contain_service('ironic-inspector-dnsmasq').with(
-        'hasstatus' => true,
-        'tag'       => 'ironic-inspector-dnsmasq-service',
-      )
+      if platform_params.has_key?(:inspector_dnsmasq_package)
+        is_expected.to contain_service('ironic-inspector-dnsmasq').with(
+          'hasstatus' => true,
+          'tag'       => 'ironic-inspector-dnsmasq-service',
+        )
+      end
     end
 
     it 'configures inspector.conf' do
@@ -127,14 +129,6 @@ describe 'ironic::inspector' do
       is_expected.to contain_ironic_inspector_config('port_physnet/cidr_map').with_value('')
     end
 
-    it 'should contain file /etc/ironic-inspector/inspector.conf' do
-      is_expected.to contain_file('/etc/ironic-inspector/inspector.conf').with(
-        'ensure'  => 'present',
-        'owner'   => 'ironic-inspector',
-        'group'   => 'ironic-inspector',
-        'require' => 'Anchor[ironic-inspector::config::begin]',
-      )
-    end
     it 'should contain file /etc/ironic-inspector/dnsmasq.conf' do
       is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with(
         'ensure'  => 'present',
