@@ -30,6 +30,7 @@ describe 'ironic::logging' do
      :log_facility                   => 'LOG_FOO',
      :log_dir                        => '/var/log',
      :log_file                       => '/var/log/ironic/ironic.log',
+     :watch_log_file                 => true,
      :debug                          => true,
     }
   end
@@ -78,6 +79,7 @@ describe 'ironic::logging' do
         :syslog_log_facility => '<SERVICE DEFAULT>',
         :log_dir             => '/var/log/ironic',
         :log_file            => '<SERVICE DEFAULT>',
+        :watch_log_file      => '<SERVICE DEFAULT>',
         :debug               => '<SERVICE DEFAULT>',
       )
     end
@@ -93,6 +95,7 @@ describe 'ironic::logging' do
         :syslog_log_facility => 'LOG_FOO',
         :log_dir             => '/var/log',
         :log_file            => '/var/log/ironic/ironic.log',
+        :watch_log_file      => true,
         :debug               => true,
       )
     end
